@@ -44,11 +44,11 @@ public:
 			return (iport == 0 || port == iport);
 
 		/* Endswith (.domain.com or .domain.com:80) */
-		if (ihost[0] == '.' && host.find(ihost) == host.size() - ihost.size())
+		if (ihost[0] == '.' && host.find(ihost) == host.size() - ihost.size() && host.size() >= ihost.size())
 			return (iport == 0 || port == iport);
 
 		/* Glob (*.domain.com or *.domain.com:80) */
-		if (ihost[0] == '*' && host.find(ihost.substr(1)) == host.size() - ihost.substr(1).size())
+		if (ihost[0] == '*' && host.find(ihost.substr(1)) == host.size() - ihost.substr(1).size() && host.size() >= ihost.substr(1).size()) 
 			return (iport == 0 || port == iport);
 
 		/* No match was found */
